@@ -60,8 +60,7 @@ use Log::Any::Adapter;
 use Params::Validate qw( :all );
 use Scalar::Util qw( looks_like_number );
 use Try::Tiny;
-use Web::MREST::CLI::UserAgent qw( send_req );
-use Web::MREST::Util qw( normalize_filespec );
+use Web::MREST::CLI::UserAgent qw( normalize_filespec send_req );
 
 
 
